@@ -202,15 +202,20 @@ async def start_subprocess(
             params.append(arg)
 
     if os.name == "nt":
+        info = subprocess.STARTUPINFO()
+        info.dwFlags = subprocess.STARTF_USESHOWWINDOW
+        info.wShowWindow = subprocess.SW_HIDE
+
         process = await asyncio.create_subprocess_exec(
             "cmd",
             "/c",
-            os.path.join(python_dir, "pythonw"),
+            os.path.join(python_dir, "python"),
             *params,
             stdout=stdout,
             stderr=stderr,
             stdin=stdin,
-            creationflags=subprocess.DETACHED_PROCESS | subprocess.CREATE_NO_WINDOW
+            startupinfo=info,
+            creationflags=subprocess.CREATE_NEW_PROCESS_GROUP | subprocess.CREATE_NEW_CONSOLE
         )
     else:
         raise NotImplementedError()
